%define debug_package %{nil}
%define plugin_root /opt/plugins
%define lib_root /opt/monitor/op5/check_vmware
%define config_root /etc/op5/check_vmware
%define user monitor
%define executable_name check_vmware_v2

Summary: Monitor plugin for running VMware checks
Name: naemon-check-vmware
Version: %{op5version}
Release: %{op5release}%{?dist}
URL: https://www.itrsgroup.com
Vendor: OP5 AB
License: OP5 EULA
Group: Applications/Internet

Source: %{name}-%{version}.tar.gz
BuildRoot: %{_tmppath}/%{name}-%{version}

Requires: bash, redis, python3
Requires: op5-monitor-user
%systemd_requires
BuildRequires: m4
BuildRequires: python3-devel

%description
Monitor plugin for running VMware checks.

The plugin has a service that runs in the background to avoid making a new
HTTP connection to vmware for every check. Before starting the service you
also need to start Redis. Run the commands `systemctl start redis` followed
by `systemctl start check_vmware`. To make sure the services start after a
system reboot, you also need to enable them by running the commands
`systemctl enable redis` and `systemctl enable check_vmware`.

For more information about installing and running the plugin, see the README
file.

%prep
%setup -q

%build
# Create gunicorn config file.
%{__cat} <<EOF >gunicorn.cfg
"""
See http://docs.gunicorn.org/en/stable/settings.html for documentation on the available
Gunicorn configuration.
"""

bind = 'localhost:8000'
workers = 3
worker_class = 'gevent'
worker_connections = 100
EOF

# Create flask config file.
%{__cat} <<EOF >service.cfg
"""
See README.md for documentation on the available Check VMware service config.

See https://flask.pocoo.org/docs/config/ for documentation on the available
Flask configuration.

See https://flask-caching.readthedocs.io/en/latest/#configuring-flask-caching
for documentation on the available Flask-Caching configuration.
"""

EOF
# Magic line to copy existing defaults from config.py, commented.
%{__awk} '/^#/ { f = 1 } f' check_vmware/service/config.py | %{__awk} '/^[A-Za-z_]/ {print "#" $0; next} 1' >>service.cfg

# Create sysconfig and service files from m4 templates.
for src in op5build/*.m4
do
	m4 -D PREFIX_DIR=%{lib_root} -D CONFIG_DIR=%{config_root} -D SERVICE_USER=%{user} \
		-D PYTHON=%{__python3} \
		-D PYTHON_SITELIB="%(echo %python3_sitelib | sed -e 's|/usr|%{lib_root}|')" \
		-D PYTHON_SITEARCH="%(echo %python3_sitearch | sed -e 's|/usr|%{lib_root}|')" \
		$src > ${src%.m4}
done

%install
%{__install} -Dp -m0644 README.md %{buildroot}%{lib_root}/README.md
%{__install} -Dp -m0644 LICENSE.txt %{buildroot}%{lib_root}/LICENSE.txt
%{__install} -Dp -m0644 MANIFEST.in %{buildroot}%{lib_root}/MANIFEST.in
%{__install} -Dp -m0644 gunicorn.cfg %{buildroot}%{config_root}/gunicorn.cfg
%{__install} -Dp -m0644 service.cfg %{buildroot}%{config_root}/service.cfg
%{__install} -Dp -m0755 op5build/entrypoint.sh %{buildroot}%{plugin_root}/%{executable_name}
%{__install} -Dp -m0644 op5build/check_vmware.service %{buildroot}%{_unitdir}/check_vmware.service
%{__install} -Dp -m0644 op5build/sysconfig %{buildroot}%{_sysconfdir}/sysconfig/check_vmware
%{__cp} -R vsan_sdk %{buildroot}%{lib_root}/vsan_sdk

# Install Python binary packages built in pre-build step:

# Upgrade to pip version used for building the wheels in pre-build step
%{__python3} -m pip install --user --no-index -f dist/ --upgrade pip

# Install check_vmware and its dependencies
%{__rm} dist/pip-*.whl
%{__python3} -m pip install -I --no-index --no-warn-script-location --no-deps \
    --isolated --prefix %{lib_root} --root %{buildroot} dist/*.whl

%post
# start and enable
systemctl daemon-reload || :
systemctl start redis || :
systemctl start check_vmware || :

systemctl enable redis || :
systemctl enable check_vmware || :

# Remove artifacts from previous versions.
%{__rm} -rf %{lib_root}/venv || :
%{__rm} -rf %{lib_root}/dist || :

%postun
%systemd_postun_with_restart check_vmware.service

%clean
%{__rm} -rf %{buildroot}

%files
%{lib_root}/bin
%{lib_root}/include
%{lib_root}/lib
%{lib_root}/lib64
%{lib_root}/vsan_sdk
%doc %{lib_root}/README.md
%doc %{lib_root}/LICENSE.txt
%doc %{lib_root}/MANIFEST.in
%{plugin_root}/%{executable_name}
%config(noreplace) %{_unitdir}/check_vmware.service
%config(noreplace) %{config_root}/gunicorn.cfg
%config(noreplace) %attr(600, %{user}, root) %{config_root}/service.cfg
%{_sysconfdir}/sysconfig/check_vmware

%changelog
* Wed Jun  9 2021 Petter Nyström <pnystrom@itrsgroup.com> - v2021.7.1
- Install check_vmware into prefix in buildtime to replace creating virtualenv
  in post script.
- Replace pipenv with poetry for building and depedency handling.
* Wed Apr  7 2021 Aksel Sjögren <asjogren@itrsgroup.com> - v2021.5.1
- Remove downloading of Python dependencies.
* Thu Jan 28 2021 Petter Nyström <support@op5.com> - v0.2.0
- Remove EL6 and python34 support
* Wed Oct 28 2020 Erik Sjöström <support@op5.com> - v0.1.17
- Remove build artifacts
* Tue Feb 5 2019 Petter Nyström <support@op5.com> - v0.1.16
- Package dependencies in install step for offline installation
* Tue Jan 22 2019 Petter Nyström <support@op5.com> - v0.1.15
- Remove plugin metadata file, it will be added to the plugins-metadata repo instead.
* Mon Jan 7 2019 Petter Nyström <support@op5.com> - v0.1.14
- Run the Gunicorn service as the monitor user, not root
* Thu Jul 19 2018 Jacob Hansen <support@op5.com> - v0.1.11
- Start the check_vmware service after install and at boot
* Tue Jul 10 2018 Petter Nyström <support@op5.com> - v0.1.10
- Install config files under /etc/op5/check_vmware
* Mon Jul 9 2018 Petter Nyström <support@op5.com> - v0.1.9
- Use python3.4 on both EL6 and EL7
* Thu Jun 28 2018 Petter Nyström <support@op5.com> - v0.1.8
- Add LICENSE.txt file
* Tue Mar 6 2018 Petter Nyström <support@op5.com> - v0.1.5
- Use pipenv to sync version dependencies
* Thu Mar 1 2018 Petter Nyström <support@op5.com> - v0.1.5
- Use config(noreplace) macro instead of config
* Tue Feb 13 2018 Petter Nyström <support@op5.com> - v0.0.10
- Install init script in /etc/init.d/ instead of /etc/init
* Tue Jan 16 2018 Petter Nyström <support@op5.com> - v0.0.6
- Install check_vmware command
* Mon Jan 8 2018 Erik Mellegård <support@op5.com> - v0.0.4
- Add project to CI pipeline (needs some tweaking)
* Mon Jan 8 2018 Erik Mellegård <support@op5.com> - v0.0.3
- Add plugin metadata file. Add requirements. Set 2 workers as default for service.
* Thu Jan 4 2018 Erik Mellegård <support@op5.com> - v0.0.2
- Add shell script that calls virtualenv python executable, so that help text in monitor displays correct help text
* Tue Jan 2 2018 Erik Mellegård <support@op5.com> - v0.0.1
- Initial attempt.
